<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\Yoast SEO
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		3.5
 * @version		3.8.3
 */

namespace WeCodeArt\Support;

if ( ! defined( 'ABSPATH' ) ) exit;

use WeCodeArt\Core\Content;
use WeCodeArt\Utilities\Markup;
use WeCodeArt\Utilities\Helpers;
use WeCodeArt\Utilities\Callbacks;

/**
 * WPSEO Integration
 */
class WordPressSeo {

	use \WeCodeArt\Singleton; 

	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {
		if( apply_filters( 'wecodeart/filter/support/breadcrumbs/woocommerce-yoast', true )
		&& Helpers::detect_plugin( [ 'classes' => [ 'woocommerce' ] ] ) ) {
			remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
		}

		add_action( 'wecodeart/hook/inner/top', [ $this, 'render_yoast_breadcrumbs' ], 30 );
	}

	/**
	 * Yoast BreadCrumbs
	 *
	 * @since   3.5
	 * @version 3.8.3
	 *
	 * @return  void
	 */
	public function render_yoast_breadcrumbs() {
		if( Callbacks::is_front_page() ) return;

		$options = Content::get_contextual_options();
		
		Markup::wrap( 'breadcrumbs', [
			[ 'tag' => 'div', 'attrs' => [ 'class' => 'breadcrumbs', 'id' => 'breadcrumb' ] ],
			[ 'tag' => 'div', 'attrs' => [ 'class' => $options['container'] ] ],
			[ 'tag' => 'div', 'attrs' => [ 'class' => 'breadcrumbs__list' ] ]
		], 'yoast_breadcrumb' ); 
	}
}