/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt FrameWork
 * @subpackage 	Admin/Notifications
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		3.8.1
 * @version		3.8.1
 */

(function ($) {

	/**
	 * Handles admin notification dismiss/transients.
	 *
	 * @since 3.8.1
	 */
	Notification = {

		/**
		 * Initialize
		 *
		 * @since 	3.8.1
		 * @method 	init
		 */
		init: function () {
			this._bind();
		},

		/**
		 * Binds events for notification buttons
		 *
		 * @since 	3.8.1
		 * @access 	private
		 * @method 	_bind
		 */
		_bind: () => {
			$(document).on('click', '.wca-notice__close', Notification._dismissNew);
			$(document).on('click', '.wca-notice .notice-dismiss', Notification._dismiss);
		},

		_dismiss: function (e) {
			e.preventDefault();

			const repeat_after = $(this).parents('.wca-notice').data('repeat') || '';
			const notice_id = $(this).parents('.wca-notice').attr('id') || '';

			Notification._ajax(notice_id, repeat_after);
		},

		_dismissNew: function (e) {
			e.preventDefault();

			const repeat_after = $(this).data('repeat') || '';
			const notice_id = $(this).parents('.wca-notice').attr('id') || '';

			const $el = $(this).parents('.wca-notice');

			$el.fadeTo(100, 0, () => $el.slideUp(100, () => $el.remove()));

			Notification._ajax(notice_id, repeat_after);

			const link = $(this).attr('href') || '';
			const target = $(this).attr('target') || '';

			if ('' !== link && '_blank' === target) {
				window.open(link, '_blank');
			}
		},

		_ajax: (notice_id, repeat_after) => {

			if ('' === notice_id) {
				return;
			}

			$.ajax({
				url: ajaxurl,
				type: 'POST',
				data: {
					action: 'wecodeart_notification_dismiss',
					notice_id: notice_id,
					repeat_after: parseInt(repeat_after),
				},
			});

		}
	};

	$(() => Notification.init());
})(jQuery);